==> kube-integration-1.15.26-api.tgz: package/server/api/kube-native/secrets/controller.js <==
'use strict';

const _                          = require('lodash');
const Promise                    = require('bluebird');
const logger                     = require('cf-logs');
const RegistryCredentialsManager = require('@codefresh-io/registries-credentials');
const ResponseHandler            = require('./../../../helpers/ResponseHandler');
const BaseCrudController         = require('./../../crud.base.controller');
const globalLabels               = require('./../../../../lib/labels');
const secretLabels               = require('./../../../../lib/kube-native/secret/secret.labels');
const CFError = require('cf-errors');
class Controller extends BaseCrudController {
    constructor() {
        super({
            lookForNamespaces: true
        });
    }

    /**
     *
     * @param request
     * @param response
     * @param next
     * @flow:
     *  Get the registry name from the body
     *  Ensure the registry exist on accounts registries
     *  Check if secret exist on the cluster
     *  Get credentials to the registry
     *  Build secret
     */
    createImagePullSecret(request, response, next) {
        const account            = request.account;
        const user               = request.user;
        const bodyRegistries     = _.get(request, 'body.accountRegistries');
        const resitries          = _.get(account, 'integrations.registries', []);
        const accountsRegistries = bodyRegistries ? bodyRegistries : resitries;
        const registryName       = _.get(request, 'body.registry');
        const namespaces         = request.namespaces;
        const kubeManager        = request.kubeManager;
        const secretController   = kubeManager.getSecretController.bind(kubeManager);


        Promise.map(accountsRegistries, (registry) => {
            if (registry.name === registryName) {
                return registry;
            }
        })
            .then(_.compact)
            .then(_.head) // should be only one
            .then((registry) => {
                if (!registry) {
                    throw new CFError({
                        message: `${registryName} not found for account ${account._id}`,
                        regocnized: true,
                    });
                }
                return registry;
            })
            .then((registry) => {
                const manager = RegistryCredentialsManager.create(registry);
                return Promise.all([
                    manager.getDomain(),
                    manager.getCredentials(),
                    Promise.resolve(registry)
                ]);
            })
            .then(([domain, credentials, usersRegistry]) => {
                return Promise.map((namespaces), (ns) => {

                    return secretController(ns)
                        .save({
                            domain,
                            ns,
                            name: registryName,
                            labels: {
                                [globalLabels.ACCOUNT_NAME.key]: account.name,
                                [globalLabels.USER_NAME.key]: user.userName,
                                [secretLabels.IMAGE_PULL_SECRET_REGISTRY_DOMAIN.key]: usersRegistry.domain,
                                [secretLabels.IMAGE_PULL_SECRET_REGISTRY_PROVIDER.key]: usersRegistry.provider,
                                [secretLabels.IMAGE_PULL_SECRET_REGISTRY_ID.key]: usersRegistry._id,
                                [secretLabels.IMAGE_PULL_SECRET_REGISTRY_NAME.key]: usersRegistry.name,
                            },
                            credentials,
                        });
                });

            })
            .map((secret) => secret.getBasicData())
            .then((data) => {
                if (_.size(namespaces) === 1) {
                    return _.head(data);
                }
                return data;
            })
            .then(ResponseHandler.respondWithResult(response, 201))
            .done(next, next);
    }

}

module.exports = new Controller();

==> kube-integration-1.15.32-api.tgz: package/server/api/kube-native/secrets/controller.js <==
'use strict';

const _                          = require('lodash');
const Promise                    = require('bluebird');
const {
    registries: { GcrRegistry, EcrRegistry, StandardRegistry }
  } = require('nodegistry');
const ResponseHandler            = require('./../../../helpers/ResponseHandler');
const BaseCrudController         = require('./../../crud.base.controller');
const globalLabels               = require('./../../../../lib/labels');
const secretLabels               = require('./../../../../lib/kube-native/secret/secret.labels');
const CFError = require('cf-errors');

function create(options) {
    switch (options.kind) {
        case 'google':
            return new GcrRegistry(options);
        case 'amazon':
            return new EcrRegistry(options);
        case 'standard':
            return new StandardRegistry(options);
        default:
            throw new CFError(`Unknown registry kind '${options.kind}'`)
    }
  }

class Controller extends BaseCrudController {
    constructor() {
        super({
            lookForNamespaces: true
        });
    }

    /**
     *
     * @param request
     * @param response
     * @param next
     * @flow:
     *  Get the registry name from the body
     *  Ensure the registry exist on accounts registries
     *  Check if secret exist on the cluster
     *  Get credentials to the registry
     *  Build secret
     */
    createImagePullSecret(request, response, next) {
        const account            = request.account;
        const user               = request.user;
        const bodyRegistries     = _.get(request, 'body.accountRegistries');
        const resitries          = _.get(account, 'integrations.registries', []);
        const accountsRegistries = bodyRegistries ? bodyRegistries : resitries;
        const registryName       = _.get(request, 'body.registry');
        const namespaces         = request.namespaces;
        const kubeManager        = request.kubeManager;
        const secretController   = kubeManager.getSecretController.bind(kubeManager);


        Promise.map(accountsRegistries, (registry) => {
            if (registry.name === registryName) {
                return registry;
            }
        })
            .then(_.compact)
            .then(_.head) // should be only one
            .then((registry) => {
                if (!registry) {
                    throw new CFError({
                        message: `${registryName} not found for account ${account._id}`,
                        regocnized: true,
                    });
                }
                return registry;
            })
            .then((registry) => {
                const manager = create(registry);
                return Promise.all([
                    manager.getDomain(),
                    manager.getCredentials(),
                    Promise.resolve(registry)
                ]);
            })
            .then(([domain, credentials, usersRegistry]) => {
                return Promise.map((namespaces), (ns) => {

                    return secretController(ns)
                        .save({
                            domain,
                            ns,
                            name: registryName,
                            labels: {
                                [globalLabels.ACCOUNT_NAME.key]: account.name,
                                [globalLabels.USER_NAME.key]: user.userName,
                                [secretLabels.IMAGE_PULL_SECRET_REGISTRY_DOMAIN.key]: usersRegistry.domain,
                                [secretLabels.IMAGE_PULL_SECRET_REGISTRY_PROVIDER.key]: usersRegistry.provider,
                                [secretLabels.IMAGE_PULL_SECRET_REGISTRY_ID.key]: usersRegistry._id,
                                [secretLabels.IMAGE_PULL_SECRET_REGISTRY_NAME.key]: usersRegistry.name,
                            },
                            credentials,
                        });
                });

            })
            .map((secret) => secret.getBasicData())
            .then((data) => {
                if (_.size(namespaces) === 1) {
                    return _.head(data);
                }
                return data;
            })
            .then(ResponseHandler.respondWithResult(response, 201))
            .done(next, next);
    }

}

module.exports = new Controller();
